@@ -667,24 +667,25 @@ class Backend implements BackendInterface, SingletonInterface
         if ($parentObject->_getProperty(AbstractDomainObject::PROPERTY_LOCALIZED_UID) !== null) {
             $parentUid = $parentObject->_getProperty(AbstractDomainObject::PROPERTY_LOCALIZED_UID);
         }
-        $row = [
-            $columnMap->getParentKeyFieldName() => (int)$parentUid,
-            $columnMap->getChildKeyFieldName() => (int)$object->getUid(),
-            $columnMap->getChildSortByFieldName() => $sortingPosition !== null ? (int)$sortingPosition : 0,
-        ];
-        $relationTableName = $columnMap->getRelationTableName();
+        $row = [];
+        if ($columnMap->getParentKeyFieldName() !== null) {
+            $row[$columnMap->getParentKeyFieldName()] = (int)$parentUid;
+        }
+        if ($columnMap->getChildKeyFieldName() !== null) {
+            $row[$columnMap->getChildKeyFieldName()] = (int)$object->getUid();
+        }
+        if ($columnMap->getChildSortByFieldName() !== null) {
+            $row[$columnMap->getChildSortByFieldName()] = $sortingPosition !== null ? (int)$sortingPosition : 0;
+        }
+        $relationTableName = $columnMap->getRelationTableName() ?? '';
         if (isset($GLOBALS['TCA'][$relationTableName])) {
             $row[AbstractDomainObject::PROPERTY_PID] = $this->determineStoragePageIdForNewRecord();
         }
-        $relationTableMatchFields = $columnMap->getRelationTableMatchFields();
-        if (is_array($relationTableMatchFields)) {
-            $row = array_merge($relationTableMatchFields, $row);
-        }
+        $relationTableMatchFields = $columnMap->getRelationTableMatchFields() ?? [];
+        $row = array_merge($relationTableMatchFields, $row);
         // @deprecated since v12. Remove in v13 with other MM_insert_fields places.
-        $relationTableInsertFields = $columnMap->getRelationTableInsertFields();
-        if (is_array($relationTableInsertFields)) {
-            $row = array_merge($relationTableInsertFields, $row);
-        }
+        $relationTableInsertFields = $columnMap->getRelationTableInsertFields() ?? [];
+        $row = array_merge($relationTableInsertFields, $row);
         $res = $this->storageBackend->addRow($relationTableName, $row, true);
         return $res;
     }
@@ -702,20 +703,20 @@ class Backend implements BackendInterface, SingletonInterface
     {
         $dataMap = $this->dataMapFactory->buildDataMap(get_class($parentObject));
         $columnMap = $dataMap->getColumnMap($propertyName);
-        $row = [
-            $columnMap->getParentKeyFieldName() => (int)$parentObject->getUid(),
-            $columnMap->getChildKeyFieldName() => (int)$object->getUid(),
-            $columnMap->getChildSortByFieldName() => (int)$sortingPosition,
-        ];
-        $relationTableName = $columnMap->getRelationTableName();
-        $relationTableMatchFields = $columnMap->getRelationTableMatchFields();
-        if (is_array($relationTableMatchFields)) {
-            $row = array_merge($relationTableMatchFields, $row);
+        $row = [];
+        if ($columnMap->getParentKeyFieldName() !== null) {
+            $row[$columnMap->getParentKeyFieldName()] = (int)$parentObject->getUid();
         }
-        $this->storageBackend->updateRelationTableRow(
-            $relationTableName,
-            $row
-        );
+        if ($columnMap->getChildKeyFieldName() !== null) {
+            $row[$columnMap->getChildKeyFieldName()] = (int)$object->getUid();
+        }
+        if ($columnMap->getChildSortByFieldName() !== null) {
+            $row[$columnMap->getChildSortByFieldName()] = (int)$sortingPosition;
+        }
+        $relationTableName = $columnMap->getRelationTableName();
+        $relationTableMatchFields = $columnMap->getRelationTableMatchFields() ?? [];
+        $row = array_merge($relationTableMatchFields, $row);
+        $this->storageBackend->updateRelationTableRow($relationTableName, $row);
         return true;
     }
 
@@ -731,13 +732,12 @@ class Backend implements BackendInterface, SingletonInterface
         $dataMap = $this->dataMapFactory->buildDataMap(get_class($parentObject));
         $columnMap = $dataMap->getColumnMap($parentPropertyName);
         $relationTableName = $columnMap->getRelationTableName();
-        $relationMatchFields = [
-            $columnMap->getParentKeyFieldName() => (int)$parentObject->getUid(),
-        ];
-        $relationTableMatchFields = $columnMap->getRelationTableMatchFields();
-        if (is_array($relationTableMatchFields)) {
-            $relationMatchFields = array_merge($relationTableMatchFields, $relationMatchFields);
+        $relationMatchFields = [];
+        if ($columnMap->getParentKeyFieldName() !== null) {
+            $relationMatchFields[$columnMap->getParentKeyFieldName()] = (int)$parentObject->getUid();
         }
+        $relationTableMatchFields = $columnMap->getRelationTableMatchFields() ?? [];
+        $relationMatchFields = array_merge($relationTableMatchFields, $relationMatchFields);
         $this->storageBackend->removeRow($relationTableName, $relationMatchFields, false);
         return true;
     }
@@ -755,14 +755,15 @@ class Backend implements BackendInterface, SingletonInterface
         $dataMap = $this->dataMapFactory->buildDataMap(get_class($parentObject));
         $columnMap = $dataMap->getColumnMap($parentPropertyName);
         $relationTableName = $columnMap->getRelationTableName();
-        $relationMatchFields = [
-            $columnMap->getParentKeyFieldName() => (int)$parentObject->getUid(),
-            $columnMap->getChildKeyFieldName() => (int)$relatedObject->getUid(),
-        ];
-        $relationTableMatchFields = $columnMap->getRelationTableMatchFields();
-        if (is_array($relationTableMatchFields)) {
-            $relationMatchFields = array_merge($relationTableMatchFields, $relationMatchFields);
+        $relationMatchFields = [];
+        if ($columnMap->getParentKeyFieldName() !== null) {
+            $relationMatchFields[$columnMap->getParentKeyFieldName()] = (int)$parentObject->getUid();
         }
+        if ($columnMap->getChildKeyFieldName() !== null) {
+            $relationMatchFields[$columnMap->getChildKeyFieldName()] = (int)$relatedObject->getUid();
+        }
+        $relationTableMatchFields = $columnMap->getRelationTableMatchFields() ?? [];
+        $relationMatchFields = array_merge($relationTableMatchFields, $relationMatchFields);
         $this->storageBackend->removeRow($relationTableName, $relationMatchFields, false);
         return true;
     }
